@@ -109,9 +109,9 @@
 #include <structure.h>
 
 static FILE *file_asn1;			/* Pointer to file to parse */
-static asn1_retCode result_parse;	/* result of the parser
+static int result_parse;	/* result of the parser
 					   algorithm */
-static ASN1_TYPE p_tree;		/* pointer to the root of the
+static asn1_node p_tree;		/* pointer to the root of the
 					   structure created by the
 					   parser*/
 static unsigned long lineNumber;	/* line number describing the
@@ -248,7 +248,7 @@ typedef union YYSTYPE
 
   unsigned int constant;
   char str[ASN1_MAX_NAME_SIZE+1];
-  ASN1_TYPE node;
+  asn1_node node;
 
 
 
@@ -491,7 +491,7 @@ union yyalloc
 /* YYNNTS -- Number of nonterminals.  */
 #define YYNNTS  43
 /* YYNRULES -- Number of rules.  */
-#define YYNRULES  99
+#define YYNRULES  100
 /* YYNRULES -- Number of states.  */
 #define YYNSTATES  190
 
@@ -551,7 +551,8 @@ static const yytype_uint16 yyprhs[] =
      195,   197,   199,   201,   203,   205,   207,   209,   211,   213,
      215,   217,   219,   222,   224,   227,   230,   233,   235,   239,
      244,   248,   253,   258,   262,   267,   272,   274,   279,   283,
-     291,   298,   303,   305,   307,   309,   312,   317,   321,   323
+     291,   298,   303,   305,   307,   309,   312,   317,   321,   323,
+     325
 };
 
 /* YYRHS -- A `-1'-separated list of the rules' RHS.  */
@@ -589,7 +590,7 @@ static const yytype_int8 yyrhs[] =
       -1,     5,     5,     3,    49,    62,    50,    -1,     5,     7,
        3,    56,    -1,    89,    -1,    90,    -1,    91,    -1,    92,
       91,    -1,     5,    49,    62,    50,    -1,     5,    49,    50,
-      -1,    29,    -1,    30,    -1
+      -1,     5,    -1,    29,    -1,    30,    -1
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
@@ -604,7 +605,8 @@ static const yytype_uint16 yyrline[] =
      276,   277,   278,   279,   280,   281,   282,   283,   284,   285,
      286,   289,   290,   295,   296,   299,   302,   305,   306,   310,
      312,   314,   319,   321,   323,   328,   332,   333,   338,   341,
-     345,   350,   356,   357,   360,   361,   365,   368,   392,   393
+     345,   350,   356,   357,   360,   361,   365,   368,   370,   394,
+     395
 };
 #endif
 
@@ -661,7 +663,8 @@ static const yytype_uint8 yyr1[] =
       80,    80,    80,    80,    80,    80,    80,    80,    80,    80,
       80,    81,    81,    82,    82,    82,    83,    84,    84,    85,
       85,    85,    86,    86,    86,    87,    88,    88,    89,    90,
-      90,    90,    91,    91,    92,    92,    93,    93,    94,    94
+      90,    90,    91,    91,    92,    92,    93,    93,    93,    94,
+      94
 };
 
 /* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
@@ -676,7 +679,8 @@ static const yytype_uint8 yyr2[] =
        1,     1,     1,     1,     1,     1,     1,     1,     1,     1,
        1,     1,     2,     1,     2,     2,     2,     1,     3,     4,
        3,     4,     4,     3,     4,     4,     1,     4,     3,     7,
-       6,     4,     1,     1,     1,     2,     4,     3,     1,     1
+       6,     4,     1,     1,     1,     2,     4,     3,     1,     1,
+       1
 };
 
 /* YYDEFACT[STATE-NAME] -- Default reduction number in state STATE-NUM.
@@ -684,8 +688,8 @@ static const yytype_uint8 yyr2[] =
    means the default is an error.  */
 static const yytype_uint8 yydefact[] =
 {
-       0,     0,     0,     0,     0,     1,     0,     8,     9,    97,
-      16,    18,     0,    98,    99,     0,     0,    96,    19,     0,
+       0,    98,     0,     0,     0,     1,     0,     8,     9,    97,
+      16,    18,     0,    99,   100,     0,     0,    96,    19,     0,
        0,     0,    17,     0,     0,    92,    93,    94,     0,     0,
        0,     0,     0,     2,    95,    56,    33,     0,     0,     0,
        0,     0,    37,    70,    86,     0,    38,    39,    44,     0,
@@ -1669,7 +1673,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 121 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_DEFINITIONS|(yyvsp[(3) - (8)].constant));
+    {(yyval.node)=_asn1_add_static_node(TYPE_DEFINITIONS|(yyvsp[(3) - (8)].constant));
                     _asn1_set_name((yyval.node),_asn1_get_name((yyvsp[(1) - (8)].node)));
                     _asn1_set_name((yyvsp[(1) - (8)].node),"");
                     _asn1_set_right((yyvsp[(1) - (8)].node),(yyvsp[(7) - (8)].node));
@@ -1747,7 +1751,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 151 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_CONSTANT);
+    {(yyval.node)=_asn1_add_static_node(TYPE_CONSTANT);
                                        _asn1_set_value((yyval.node),(yyvsp[(2) - (3)].str),strlen((yyvsp[(2) - (3)].str))+1);}
     break;
 
@@ -1755,7 +1759,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 153 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_CONSTANT);
+    {(yyval.node)=_asn1_add_static_node(TYPE_CONSTANT);
 	                               _asn1_set_name((yyval.node),(yyvsp[(1) - (4)].str));
                                        _asn1_set_value((yyval.node),(yyvsp[(3) - (4)].str),strlen((yyvsp[(3) - (4)].str))+1);}
     break;
@@ -1779,7 +1783,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 163 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_CONSTANT);
+    {(yyval.node)=_asn1_add_static_node(TYPE_CONSTANT);
                                    _asn1_set_value((yyval.node),(yyvsp[(1) - (1)].str),strlen((yyvsp[(1) - (1)].str))+1);}
     break;
 
@@ -1787,7 +1791,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 165 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_CONSTANT);
+    {(yyval.node)=_asn1_add_static_node(TYPE_CONSTANT);
 	                            _asn1_set_name((yyval.node),(yyvsp[(1) - (4)].str));
                                     _asn1_set_value((yyval.node),(yyvsp[(3) - (4)].str),strlen((yyvsp[(3) - (4)].str))+1);}
     break;
@@ -1832,7 +1836,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 180 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_TAG);
+    {(yyval.node)=_asn1_add_static_node(TYPE_TAG);
                             _asn1_set_value((yyval.node),(yyvsp[(2) - (3)].str),strlen((yyvsp[(2) - (3)].str))+1);}
     break;
 
@@ -1840,7 +1844,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 182 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_TAG | (yyvsp[(2) - (4)].constant));
+    {(yyval.node)=_asn1_add_static_node(TYPE_TAG | (yyvsp[(2) - (4)].constant));
                                 _asn1_set_value((yyval.node),(yyvsp[(3) - (4)].str),strlen((yyvsp[(3) - (4)].str))+1);}
     break;
 
@@ -1869,7 +1873,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 191 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_DEFAULT);
+    {(yyval.node)=_asn1_add_static_node(TYPE_DEFAULT);
                                        _asn1_set_value((yyval.node),(yyvsp[(2) - (2)].str),strlen((yyvsp[(2) - (2)].str))+1);}
     break;
 
@@ -1877,28 +1881,28 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 193 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_DEFAULT|CONST_TRUE);}
+    {(yyval.node)=_asn1_add_static_node(TYPE_DEFAULT|CONST_TRUE);}
     break;
 
   case 30:
 
 /* Line 1806 of yacc.c  */
 #line 194 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_DEFAULT|CONST_FALSE);}
+    {(yyval.node)=_asn1_add_static_node(TYPE_DEFAULT|CONST_FALSE);}
     break;
 
   case 33:
 
 /* Line 1806 of yacc.c  */
 #line 203 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_INTEGER);}
+    {(yyval.node)=_asn1_add_static_node(TYPE_INTEGER);}
     break;
 
   case 34:
 
 /* Line 1806 of yacc.c  */
 #line 204 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_INTEGER|CONST_LIST);
+    {(yyval.node)=_asn1_add_static_node(TYPE_INTEGER|CONST_LIST);
 	                                 _asn1_set_down((yyval.node),(yyvsp[(3) - (4)].node));}
     break;
 
@@ -1906,15 +1910,15 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 206 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_INTEGER);}
+    {(yyval.node)=_asn1_add_static_node(TYPE_INTEGER);}
     break;
 
   case 36:
 
 /* Line 1806 of yacc.c  */
 #line 208 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_INTEGER|CONST_MIN_MAX);
-                                         _asn1_set_down((yyval.node),_asn1_add_node(TYPE_SIZE));
+    {(yyval.node)=_asn1_add_static_node(TYPE_INTEGER|CONST_MIN_MAX);
+                                         _asn1_set_down((yyval.node),_asn1_add_static_node(TYPE_SIZE));
                                          _asn1_set_value(_asn1_get_down((yyval.node)),(yyvsp[(6) - (7)].str),strlen((yyvsp[(6) - (7)].str))+1);
                                          _asn1_set_name(_asn1_get_down((yyval.node)),(yyvsp[(3) - (7)].str));}
     break;
@@ -1923,28 +1927,28 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 214 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_BOOLEAN);}
+    {(yyval.node)=_asn1_add_static_node(TYPE_BOOLEAN);}
     break;
 
   case 38:
 
 /* Line 1806 of yacc.c  */
 #line 217 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_TIME|CONST_UTC);}
+    {(yyval.node)=_asn1_add_static_node(TYPE_TIME|CONST_UTC);}
     break;
 
   case 39:
 
 /* Line 1806 of yacc.c  */
 #line 218 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_TIME|CONST_GENERALIZED);}
+    {(yyval.node)=_asn1_add_static_node(TYPE_TIME|CONST_GENERALIZED);}
     break;
 
   case 40:
 
 /* Line 1806 of yacc.c  */
 #line 221 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_SIZE|CONST_1_PARAM);
+    {(yyval.node)=_asn1_add_static_node(TYPE_SIZE|CONST_1_PARAM);
 	                              _asn1_set_value((yyval.node),(yyvsp[(3) - (4)].str),strlen((yyvsp[(3) - (4)].str))+1);}
     break;
 
@@ -1952,7 +1956,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 224 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_SIZE|CONST_MIN_MAX);
+    {(yyval.node)=_asn1_add_static_node(TYPE_SIZE|CONST_MIN_MAX);
 	                              _asn1_set_value((yyval.node),(yyvsp[(3) - (7)].str),strlen((yyvsp[(3) - (7)].str))+1);
                                       _asn1_set_name((yyval.node),(yyvsp[(6) - (7)].str));}
     break;
@@ -1975,14 +1979,14 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 233 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_GENERALSTRING);}
+    {(yyval.node)=_asn1_add_static_node(TYPE_GENERALSTRING);}
     break;
 
   case 45:
 
 /* Line 1806 of yacc.c  */
 #line 234 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_GENERALSTRING|CONST_SIZE);
+    {(yyval.node)=_asn1_add_static_node(TYPE_GENERALSTRING|CONST_SIZE);
 					  _asn1_set_down((yyval.node),(yyvsp[(2) - (2)].node));}
     break;
 
@@ -1990,14 +1994,14 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 238 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_OCTET_STRING);}
+    {(yyval.node)=_asn1_add_static_node(TYPE_OCTET_STRING);}
     break;
 
   case 47:
 
 /* Line 1806 of yacc.c  */
 #line 239 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_OCTET_STRING|CONST_SIZE);
+    {(yyval.node)=_asn1_add_static_node(TYPE_OCTET_STRING|CONST_SIZE);
                                            _asn1_set_down((yyval.node),(yyvsp[(3) - (3)].node));}
     break;
 
@@ -2005,7 +2009,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 243 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_CONSTANT);
+    {(yyval.node)=_asn1_add_static_node(TYPE_CONSTANT);
 	                           _asn1_set_name((yyval.node),(yyvsp[(1) - (4)].str));
                                     _asn1_set_value((yyval.node),(yyvsp[(3) - (4)].str),strlen((yyvsp[(3) - (4)].str))+1);}
     break;
@@ -2029,21 +2033,21 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 253 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_BIT_STRING);}
+    {(yyval.node)=_asn1_add_static_node(TYPE_BIT_STRING);}
     break;
 
   case 52:
 
 /* Line 1806 of yacc.c  */
 #line 254 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_BIT_STRING|CONST_SIZE);}
+    {(yyval.node)=_asn1_add_static_node(TYPE_BIT_STRING|CONST_SIZE);}
     break;
 
   case 53:
 
 /* Line 1806 of yacc.c  */
 #line 256 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_BIT_STRING|CONST_LIST);
+    {(yyval.node)=_asn1_add_static_node(TYPE_BIT_STRING|CONST_LIST);
                                 _asn1_set_down((yyval.node),(yyvsp[(4) - (5)].node));}
     break;
 
@@ -2051,7 +2055,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 261 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_ENUMERATED|CONST_LIST);
+    {(yyval.node)=_asn1_add_static_node(TYPE_ENUMERATED|CONST_LIST);
                                 _asn1_set_down((yyval.node),(yyvsp[(3) - (4)].node));}
     break;
 
@@ -2059,14 +2063,14 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 266 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_OBJECT_ID);}
+    {(yyval.node)=_asn1_add_static_node(TYPE_OBJECT_ID);}
     break;
 
   case 56:
 
 /* Line 1806 of yacc.c  */
 #line 269 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_IDENTIFIER);
+    {(yyval.node)=_asn1_add_static_node(TYPE_IDENTIFIER);
                                        _asn1_set_value((yyval.node),(yyvsp[(1) - (1)].str),strlen((yyvsp[(1) - (1)].str))+1);}
     break;
 
@@ -2074,7 +2078,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 271 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_IDENTIFIER|CONST_SIZE);
+    {(yyval.node)=_asn1_add_static_node(TYPE_IDENTIFIER|CONST_SIZE);
                                        _asn1_set_value((yyval.node),(yyvsp[(1) - (2)].str),strlen((yyvsp[(1) - (2)].str))+1);
                                        _asn1_set_down((yyval.node),(yyvsp[(2) - (2)].node));}
     break;
@@ -2160,7 +2164,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 286 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_NULL);}
+    {(yyval.node)=_asn1_add_static_node(TYPE_NULL);}
     break;
 
   case 71:
@@ -2228,7 +2232,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 310 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_SEQUENCE);
+    {(yyval.node)=_asn1_add_static_node(TYPE_SEQUENCE);
                                               _asn1_set_down((yyval.node),(yyvsp[(3) - (4)].node));}
     break;
 
@@ -2236,7 +2240,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 312 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_SEQUENCE_OF);
+    {(yyval.node)=_asn1_add_static_node(TYPE_SEQUENCE_OF);
                                               _asn1_set_down((yyval.node),(yyvsp[(3) - (3)].node));}
     break;
 
@@ -2244,7 +2248,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 314 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_SEQUENCE_OF|CONST_SIZE);
+    {(yyval.node)=_asn1_add_static_node(TYPE_SEQUENCE_OF|CONST_SIZE);
                                             _asn1_set_right((yyvsp[(2) - (4)].node),(yyvsp[(4) - (4)].node));
                                             _asn1_set_down((yyval.node),(yyvsp[(2) - (4)].node));}
     break;
@@ -2253,7 +2257,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 319 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_SET);
+    {(yyval.node)=_asn1_add_static_node(TYPE_SET);
                                      _asn1_set_down((yyval.node),(yyvsp[(3) - (4)].node));}
     break;
 
@@ -2261,7 +2265,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 321 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_SET_OF);
+    {(yyval.node)=_asn1_add_static_node(TYPE_SET_OF);
                                      _asn1_set_down((yyval.node),(yyvsp[(3) - (3)].node));}
     break;
 
@@ -2269,7 +2273,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 323 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_SET_OF|CONST_SIZE);
+    {(yyval.node)=_asn1_add_static_node(TYPE_SET_OF|CONST_SIZE);
                                        _asn1_set_right((yyvsp[(2) - (4)].node),(yyvsp[(4) - (4)].node));
                                        _asn1_set_down((yyval.node),(yyvsp[(2) - (4)].node));}
     break;
@@ -2278,7 +2282,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 328 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_CHOICE);
+    {(yyval.node)=_asn1_add_static_node(TYPE_CHOICE);
                                              _asn1_set_down((yyval.node),(yyvsp[(3) - (4)].node));}
     break;
 
@@ -2286,15 +2290,15 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 332 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_ANY);}
+    {(yyval.node)=_asn1_add_static_node(TYPE_ANY);}
     break;
 
   case 87:
 
 /* Line 1806 of yacc.c  */
 #line 333 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_ANY|CONST_DEFINED_BY);
-                                        _asn1_set_down((yyval.node),_asn1_add_node(TYPE_CONSTANT));
+    {(yyval.node)=_asn1_add_static_node(TYPE_ANY|CONST_DEFINED_BY);
+                                        _asn1_set_down((yyval.node),_asn1_add_static_node(TYPE_CONSTANT));
 	                                _asn1_set_name(_asn1_get_down((yyval.node)),(yyvsp[(4) - (4)].str));}
     break;
 
@@ -2309,7 +2313,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 342 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_OBJECT_ID|CONST_ASSIGN);
+    {(yyval.node)=_asn1_add_static_node(TYPE_OBJECT_ID|CONST_ASSIGN);
                          _asn1_set_name((yyval.node),(yyvsp[(1) - (7)].str));
                          _asn1_set_down((yyval.node),(yyvsp[(6) - (7)].node));}
     break;
@@ -2318,7 +2322,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 346 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_OBJECT_ID|CONST_ASSIGN|CONST_1_PARAM);
+    {(yyval.node)=_asn1_add_static_node(TYPE_OBJECT_ID|CONST_ASSIGN|CONST_1_PARAM);
                          _asn1_set_name((yyval.node),(yyvsp[(1) - (6)].str));
                          _asn1_set_value((yyval.node),(yyvsp[(2) - (6)].str),strlen((yyvsp[(2) - (6)].str))+1);
                          _asn1_set_down((yyval.node),(yyvsp[(5) - (6)].node));}
@@ -2328,7 +2332,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 351 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_INTEGER|CONST_ASSIGN);
+    {(yyval.node)=_asn1_add_static_node(TYPE_INTEGER|CONST_ASSIGN);
                          _asn1_set_name((yyval.node),(yyvsp[(1) - (4)].str));
                          _asn1_set_value((yyval.node),(yyvsp[(4) - (4)].str),strlen((yyvsp[(4) - (4)].str))+1);}
     break;
@@ -2366,7 +2370,7 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 365 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_OBJECT_ID);
+    {(yyval.node)=_asn1_add_static_node(TYPE_OBJECT_ID);
                                                           _asn1_set_down((yyval.node),(yyvsp[(3) - (4)].node));
                                                           _asn1_set_name((yyval.node),(yyvsp[(1) - (4)].str));}
     break;
@@ -2375,28 +2379,36 @@ yyreduce:
 
 /* Line 1806 of yacc.c  */
 #line 368 "ASN1.y"
-    {(yyval.node)=_asn1_add_node(TYPE_OBJECT_ID);
+    {(yyval.node)=_asn1_add_static_node(TYPE_OBJECT_ID);
                                                           _asn1_set_name((yyval.node),(yyvsp[(1) - (3)].str));}
     break;
 
   case 98:
 
 /* Line 1806 of yacc.c  */
-#line 392 "ASN1.y"
-    {(yyval.constant)=CONST_EXPLICIT;}
+#line 370 "ASN1.y"
+    {(yyval.node)=_asn1_add_static_node(TYPE_OBJECT_ID);
+                                                          _asn1_set_name((yyval.node),(yyvsp[(1) - (1)].str));}
     break;
 
   case 99:
 
 /* Line 1806 of yacc.c  */
-#line 393 "ASN1.y"
+#line 394 "ASN1.y"
+    {(yyval.constant)=CONST_EXPLICIT;}
+    break;
+
+  case 100:
+
+/* Line 1806 of yacc.c  */
+#line 395 "ASN1.y"
     {(yyval.constant)=CONST_IMPLICIT;}
     break;
 
 
 
 /* Line 1806 of yacc.c  */
-#line 2400 "ASN1.c"
+#line 2412 "ASN1.c"
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -2627,7 +2639,7 @@ yyreturn:
 
 
 /* Line 2067 of yacc.c  */
-#line 397 "ASN1.y"
+#line 399 "ASN1.y"
 
 
 
@@ -2802,23 +2814,24 @@ _asn1_create_errorDescription(int error,char *errorDescription)
  *
  * Returns: %ASN1_SUCCESS if the file has a correct syntax and every
  *   identifier is known, %ASN1_ELEMENT_NOT_EMPTY if @definitions not
- *   %ASN1_TYPE_EMPTY, %ASN1_FILE_NOT_FOUND if an error occured while
+ *   %NULL, %ASN1_FILE_NOT_FOUND if an error occured while
  *   opening @file_name, %ASN1_SYNTAX_ERROR if the syntax is not
  *   correct, %ASN1_IDENTIFIER_NOT_FOUND if in the file there is an
  *   identifier that is not defined, %ASN1_NAME_TOO_LONG if in the
  *   file there is an identifier whith more than %ASN1_MAX_NAME_SIZE
  *   characters.
  **/
-asn1_retCode
-asn1_parser2tree(const char *file_name, ASN1_TYPE *definitions,
-		 char *errorDescription){
+int
+asn1_parser2tree(const char *file_name, asn1_node *definitions,
+		 char *errorDescription) 
+{
 
-  p_tree=ASN1_TYPE_EMPTY;
+  p_tree=NULL;
 
-  if(*definitions != ASN1_TYPE_EMPTY)
+  if(*definitions != NULL)
     return ASN1_ELEMENT_NOT_EMPTY;
 
-  *definitions=ASN1_TYPE_EMPTY;
+  *definitions=NULL;
 
   fileName = file_name;
 
@@ -2944,7 +2957,7 @@ int asn1_parser2array(const char *inputFileName,const char *outputFileName,
 
 	if(outputFileName == NULL){
 	  /* file_out_name = inputFileName + _asn1_tab.c */
-	  file_out_name=(char *)malloc(dot_p-inputFileName+1+
+	  file_out_name=malloc(dot_p-inputFileName+1+
 				       strlen("_asn1_tab.c"));
 	  memcpy(file_out_name,inputFileName,dot_p-inputFileName);
 	  file_out_name[dot_p-inputFileName]=0;
@@ -2958,7 +2971,7 @@ int asn1_parser2array(const char *inputFileName,const char *outputFileName,
 
 	if(vectorName == NULL){
 	  /* vector_name = file name + _asn1_tab */
-	  vector_name=(char *)malloc(dot_p-slash_p+1+
+	  vector_name=malloc(dot_p-slash_p+1+
 				     strlen("_asn1_tab"));
 	  memcpy(vector_name,slash_p,dot_p-slash_p);
 	  vector_name[dot_p-slash_p]=0;
