@@ -1,6 +1,5 @@
 /* asn1Decoding.c ---  program to generate an ASN1 type from a DER coding.
- * Copyright (C) 2002, 2006, 2007, 2008, 2009, 2010, 2011 Free Software
- * Foundation, Inc.
+ * Copyright (C) 2002-2012 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -32,12 +31,15 @@
 #include <progname.h>
 #include <version-etc.h>
 #include <read-file.h>
+#include "benchmark.h"
+
+static int decode(asn1_node definitions, const char* typeName, void* der, int der_len, int benchmark);
 
 /* This feature is available in gcc versions 2.5 and later.  */
 #if __GNUC__ < 2 || (__GNUC__ == 2 && __GNUC_MINOR__ < 5)
-# define ATTR_NO_RETRUN
+#define ATTR_NO_RETRUN
 #else
-# define ATTR_NO_RETRUN __attribute__ ((__noreturn__))
+#define ATTR_NO_RETRUN __attribute__ ((__noreturn__))
 #endif
 
 ATTR_NO_RETRUN static void
@@ -74,12 +76,11 @@ main (int argc, char *argv[])
   char *inputFileAsnName = NULL;
   char *inputFileDerName = NULL;
   char *typeName = NULL;
-  ASN1_TYPE definitions = ASN1_TYPE_EMPTY;
-  ASN1_TYPE structure = ASN1_TYPE_EMPTY;
+  asn1_node definitions = NULL;
   char errorDescription[ASN1_MAX_ERROR_DESCRIPTION_SIZE];
   int asn1_result = ASN1_SUCCESS;
   unsigned char *der;
-  int der_len = 0;
+  int der_len = 0, benchmark = 0;
   /* FILE *outputFile; */
 
   set_program_name (argv[0]);
@@ -90,7 +91,7 @@ main (int argc, char *argv[])
     {
 
       option_result =
-	getopt_long (argc, argv, "hvc", long_options, &option_index);
+	getopt_long (argc, argv, "hbvc", long_options, &option_index);
 
       if (option_result == -1)
 	break;
@@ -100,6 +101,9 @@ main (int argc, char *argv[])
 	case 'h':		/* HELP */
 	  usage (EXIT_SUCCESS);
 	  break;
+        case 'b':
+          benchmark = 1;
+          break;
 	case 'v':		/* VERSION */
 	  version_etc (stdout, program_name, PACKAGE, VERSION,
 		       "Fabio Fiorina", NULL);
@@ -196,50 +200,17 @@ main (int argc, char *argv[])
      fclose(inputFile);
    */
 
-  asn1_result = asn1_create_element (definitions, typeName, &structure);
-
-  /* asn1_print_structure(stdout,structure,"",ASN1_PRINT_ALL); */
-
-
-  if (asn1_result != ASN1_SUCCESS)
+  if (decode( definitions, typeName, der, der_len, benchmark) != ASN1_SUCCESS)
     {
-      printf ("Structure creation: %s\n", asn1_strerror (asn1_result));
       asn1_delete_structure (&definitions);
-
       free (inputFileAsnName);
       free (inputFileDerName);
       free (typeName);
       free (der);
       exit (1);
     }
-
-  asn1_result =
-    asn1_der_decoding (&structure, der, der_len, errorDescription);
-  printf ("\nDecoding: %s\n", asn1_strerror (asn1_result));
-  if (asn1_result != ASN1_SUCCESS)
-    printf ("asn1Decoding: %s\n", errorDescription);
-
-  printf ("\nDECODING RESULT:\n");
-  asn1_print_structure (stdout, structure, "", ASN1_PRINT_NAME_TYPE_VALUE);
-
- /*****************************************/
-  /* ONLY FOR TEST                         */
- /*****************************************/
-  /*
-     der_len=10000;
-     option_index=0;
-     asn1_result=asn1_read_value(structure,"?2.content",der,&der_len);
-     outputFile=fopen("encryptedData.p12","w");
-     while(der_len>0){
-     fprintf(outputFile,"%c",der[option_index]);
-     der_len--;
-     option_index++;
-     }
-     fclose(outputFile);
-   */
-
+  
   asn1_delete_structure (&definitions);
-  asn1_delete_structure (&structure);
 
   free (der);
 
@@ -252,3 +223,65 @@ main (int argc, char *argv[])
 
   exit (0);
 }
+
+static int simple_decode(asn1_node definitions, const char* typeName, void* der, int der_len, int benchmark)
+{
+  
+int asn1_result;
+asn1_node structure = NULL;
+char errorDescription[ASN1_MAX_ERROR_DESCRIPTION_SIZE];
+
+  asn1_result = asn1_create_element (definitions, typeName, &structure);
+
+  /* asn1_print_structure(stdout,structure,"",ASN1_PRINT_ALL); */
+
+
+  if (asn1_result != ASN1_SUCCESS)
+    {
+      printf ("Structure creation: %s\n", asn1_strerror (asn1_result));
+      asn1_delete_structure (&structure);
+      return asn1_result;
+    }
+
+  asn1_result =
+    asn1_der_decoding (&structure, der, der_len, errorDescription);
+
+  if (!benchmark) printf ("\nDecoding: %s\n", asn1_strerror (asn1_result));
+  if (asn1_result != ASN1_SUCCESS)
+    {
+      printf ("asn1Decoding: %s\n", errorDescription);
+      asn1_delete_structure (&structure);
+      return asn1_result;
+    }
+
+  if (!benchmark)
+    {
+      printf ("\nDECODING RESULT:\n");
+      asn1_print_structure (stdout, structure, "", ASN1_PRINT_NAME_TYPE_VALUE);
+    }
+  asn1_delete_structure (&structure);
+  return ASN1_SUCCESS;
+}
+
+static int decode(asn1_node definitions, const char* typeName, void* der, int der_len, int benchmark)
+{
+struct benchmark_st st;
+
+  if (benchmark == 0) return simple_decode(definitions, typeName, der, der_len, benchmark);
+  else
+    {
+      start_benchmark(&st);
+      
+      do
+        {
+          simple_decode(definitions, typeName, der, der_len, benchmark);
+          st.size++;
+        }
+      while(benchmark_must_finish == 0);
+      
+      stop_benchmark(&st, "structures");
+      fprintf(stdout, "\n");
+    
+    }
+  return ASN1_SUCCESS;
+}
