@@ -1,6 +1,5 @@
 /*
- * Copyright (C) 2002, 2006, 2007, 2009, 2010, 2011 Free Software
- * Foundation, Inc.
+ * Copyright (C) 2002-2012 Free Software Foundation, Inc.
  *
  * This file is part of LIBTASN1.
  *
@@ -53,13 +52,12 @@ test_type test_array[] = {
 
   /* Test ASN1_MAX_NAME_SIZE (128) */
   {12,
-   "a1234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567 ::= INTEGER",
+   "a123456789012345678901234567890123456789012345678901234567890123 ::= INTEGER",
    ASN1_SUCCESS, ""},
   {12,
-   "a12345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678901234567890123456789012345678 ::= INTEGER",
+   "a1234567890123456789012345678901234567890123456789012345678901234 ::= INTEGER",
    ASN1_NAME_TOO_LONG,
-   _FILE_ ":12: name too long (more than 128 characters)"},
-
+   _FILE_ ":12: name too long (more than 64 characters)"},
   /* Test 'check identifier' function */
   {12, "ident1 ::= ident2   ident2 ::= INTEGER",
    ASN1_SUCCESS, ""},
@@ -102,7 +100,6 @@ test_type test_array[] = {
   {20, "   oid1    OBJECT IDENTIFIER DEFAULT Oid-type1",
    ASN1_SUCCESS, ""},
 
-
   /* end */
   {0}
 };
@@ -150,20 +147,27 @@ createFile (int lineNumber, const char *line)
 int
 main (int argc, char *argv[])
 {
-  asn1_retCode result;
-  ASN1_TYPE definitions = ASN1_TYPE_EMPTY;
+  int result;
+  asn1_node definitions = NULL;
   char errorDescription[ASN1_MAX_ERROR_DESCRIPTION_SIZE];
   test_type *test;
   int errorCounter = 0, testCounter = 0;
+  int verbose = 0;
+  
+  if (argc > 1)
+    verbose = 1;
 
   fileCorrectName = getenv ("ASN1PARSER");
   if (!fileCorrectName)
     fileCorrectName = "Test_parser.asn";
 
-  printf ("\n\n/****************************************/\n");
-  printf ("/*     Test sequence : Test_parser      */\n");
-  printf ("/****************************************/\n\n");
-  printf ("ASN1PARSER: %s\n", fileCorrectName);
+  if (verbose != 0)
+    {
+      printf ("\n\n/****************************************/\n");
+      printf ("/*     Test sequence : Test_parser      */\n");
+      printf ("/****************************************/\n\n");
+      printf ("ASN1PARSER: %s\n", fileCorrectName);
+    }
 
   result = asn1_parser2tree (fileCorrectName, &definitions, errorDescription);
 
@@ -210,8 +214,11 @@ main (int argc, char *argv[])
     }
 
 
-  printf ("Total tests : %d\n", testCounter);
-  printf ("Total errors: %d\n", errorCounter);
+  if (verbose != 0)
+    {
+      printf ("Total tests : %d\n", testCounter);
+      printf ("Total errors: %d\n", errorCounter);
+    }
 
   if (errorCounter > 0)
     return 1;
